@@ -4,26 +4,26 @@ import sys
 from pdm import termui
 from pdm.cli import actions
 from pdm.cli.commands.base import BaseCommand
+from pdm.cli.filters import GroupSelection
 from pdm.cli.hooks import HookManager
-from pdm.cli.options import (
-    dry_run_option,
-    groups_group,
-    install_group,
-    lockfile_option,
-    skip_option,
-)
+from pdm.cli.options import dry_run_option, groups_group, install_group, lockfile_option, skip_option, venv_option
 from pdm.project import Project
 
 
 class Command(BaseCommand):
     """Install dependencies from lock file"""
 
+    arguments = [
+        *BaseCommand.arguments,
+        groups_group,
+        install_group,
+        dry_run_option,
+        lockfile_option,
+        skip_option,
+        venv_option,
+    ]
+
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
-        groups_group.add_to_parser(parser)
-        install_group.add_to_parser(parser)
-        dry_run_option.add_to_parser(parser)
-        lockfile_option.add_to_parser(parser)
-        skip_option.add_to_parser(parser)
         parser.add_argument(
             "--no-lock",
             dest="lock",
@@ -44,6 +44,7 @@ class Command(BaseCommand):
         hooks = HookManager(project, options.skip)
 
         strategy = actions.check_lockfile(project, False)
+        selection = GroupSelection.from_options(project, options)
         if strategy:
             if options.check:
                 project.core.ui.echo(
@@ -53,15 +54,17 @@ class Command(BaseCommand):
                 sys.exit(1)
             if options.lock:
                 project.core.ui.echo("Updating the lock file...", style="success", err=True)
-                actions.do_lock(project, strategy=strategy, dry_run=options.dry_run, hooks=hooks)
+
+                actions.do_lock(
+                    project, strategy=strategy, dry_run=options.dry_run, hooks=hooks, groups=selection.all()
+                )
 
         actions.do_sync(
             project,
-            groups=options.groups,
-            dev=options.dev,
-            default=options.default,
+            selection=selection,
             no_editable=options.no_editable,
             no_self=options.no_self,
             dry_run=options.dry_run,
+            fail_fast=options.fail_fast,
             hooks=hooks,
         )
