@@ -11,14 +11,15 @@ import sys
 from types import FrameType
 from typing import Any, Callable, Iterator, Mapping, NamedTuple, Sequence, cast
 
-from pdm import signals, termui
+from pdm import termui
 from pdm.cli.commands.base import BaseCommand
-from pdm.cli.hooks import KNOWN_HOOKS, HookManager
-from pdm.cli.options import skip_option
+from pdm.cli.hooks import HookManager
+from pdm.cli.options import skip_option, venv_option
 from pdm.cli.utils import check_project_file, get_pep582_path
 from pdm.compat import TypedDict
 from pdm.exceptions import PdmUsageError
 from pdm.project import Project
+from pdm.signals import pdm_signals
 from pdm.utils import is_path_relative_to
 
 
@@ -151,19 +152,7 @@ class TaskRunner:
         pythonpath = [get_pep582_path(project)] + [p for p in pythonpath if "pdm/pep582" not in p.replace("\\", "/")]
         project_env = project.environment
         this_path = project_env.get_paths()["scripts"]
-        python_root = os.path.dirname(project.python.executable)
-        new_path = os.pathsep.join([this_path, process_env.get("PATH", ""), python_root])
-        process_env.update(
-            {
-                "PYTHONPATH": os.pathsep.join(pythonpath),
-                "PATH": new_path,
-                "PDM_PROJECT_ROOT": str(project.root),
-            }
-        )
-        if project_env.packages_path:
-            process_env.update({"PEP582_PACKAGES": str(project_env.packages_path)})
-        if project_env.venv_path:
-            process_env.update({"VIRTUAL_ENV": str(project_env.venv_path)})
+        process_env.update(project_env.process_env)
         if env:
             process_env.update(env)
         if shell:
@@ -174,7 +163,7 @@ class TaskRunner:
             command, *args = args
             if command.endswith(".py"):
                 args = [command, *args]
-                command = str(project.python.executable)
+                command = str(project.environment.interpreter.executable)
             expanded_command = project_env.which(command)
             if not expanded_command:
                 raise PdmUsageError(f"Command [success]'{command}'[/] is not found in your PATH.")
@@ -182,7 +171,7 @@ class TaskRunner:
             real_command = os.path.realpath(expanded_command)
             expanded_args = [os.path.expandvars(arg) for arg in [expanded_command, *args]]
             if (
-                not project_env.is_global
+                project_env.is_local
                 and not site_packages
                 and (
                     os.path.basename(real_command).startswith("python")
@@ -316,9 +305,9 @@ class Command(BaseCommand):
     """Run commands or scripts with local packages loaded"""
 
     runner_cls: type[TaskRunner] = TaskRunner
+    arguments = [*BaseCommand.arguments, skip_option, venv_option]
 
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
-        skip_option.add_to_parser(parser)
         parser.add_argument(
             "-l",
             "--list",
@@ -331,7 +320,7 @@ class Command(BaseCommand):
             action="store_true",
             help="Load site-packages from the selected interpreter",
         )
-        parser.add_argument("command", nargs="?", help="The command to run")
+        parser.add_argument("script", nargs="?", help="The command to run")
         parser.add_argument(
             "args",
             nargs=argparse.REMAINDER,
@@ -346,16 +335,16 @@ class Command(BaseCommand):
             return runner.show_list()
         if options.site_packages:
             runner.global_options.update({"site_packages": options.site_packages})
-        if not options.command:
+        if not options.script:
             project.core.ui.echo(
                 "No command is given, default to the Python REPL.",
                 style="warning",
                 err=True,
             )
-            options.command = "python"
-        hooks.try_emit("pre_run", script=options.command, args=options.args)
-        exit_code = runner.run(options.command, options.args)
-        hooks.try_emit("post_run", script=options.command, args=options.args)
+            options.script = "python"
+        hooks.try_emit("pre_run", script=options.script, args=options.args)
+        exit_code = runner.run(options.script, options.args)
+        hooks.try_emit("post_run", script=options.script, args=options.args)
         sys.exit(exit_code)
 
 
@@ -374,5 +363,5 @@ def run_script_if_present(script_name: str) -> Callable:
     return handler
 
 
-for hook in KNOWN_HOOKS:
-    getattr(signals, hook).connect(run_script_if_present(hook), weak=False)
+for hook in pdm_signals:
+    pdm_signals.signal(hook).connect(run_script_if_present(hook), weak=False)
