@@ -2,19 +2,17 @@ from __future__ import annotations
 
 import argparse
 import os
-from typing import Any, Sequence
+import sys
+from functools import partial
+from typing import Any, Sequence, cast
 
+from pdm.cli.actions import print_pep582_command
 from pdm.compat import Protocol
+from pdm.project import Project
 
 
 class ActionCallback(Protocol):
-    def __call__(
-        self,
-        parser: argparse.ArgumentParser,
-        namespace: argparse.Namespace,
-        values: str | Sequence[Any] | None,
-        option_string: str | None,
-    ) -> None:
+    def __call__(self, project: Project, namespace: argparse.Namespace, values: str | Sequence[Any] | None) -> None:
         ...
 
 
@@ -33,6 +31,10 @@ class Option:
     def add_to_group(self, group: argparse._ArgumentGroup) -> None:
         group.add_argument(*self.args, **self.kwargs)
 
+    def __call__(self, func: ActionCallback) -> Option:
+        self.kwargs.update(action=CallbackAction, callback=func)
+        return self
+
 
 class CallbackAction(argparse.Action):
     def __init__(self, *args: Any, callback: ActionCallback, **kwargs: Any) -> None:
@@ -46,7 +48,10 @@ class CallbackAction(argparse.Action):
         values: str | Sequence[Any] | None,
         option_string: str | None = None,
     ) -> None:
-        return self.callback(parser, namespace, values, option_string=option_string)
+        if not hasattr(namespace, "callbacks"):
+            namespace.callbacks = []
+        callback = partial(self.callback, values=values)
+        namespace.callbacks.append(callback)
 
 
 class ArgumentGroup(Option):
@@ -133,6 +138,7 @@ dry_run_option = Option(
     help="Show the difference only and don't perform any action",
 )
 
+
 lockfile_option = Option(
     "-L",
     "--lockfile",
@@ -140,13 +146,12 @@ lockfile_option = Option(
     help="Specify another lockfile path. Default: pdm.lock. [env var: PDM_LOCKFILE]",
 )
 
-pep582_option = Option(
-    "--pep582",
-    const="AUTO",
-    metavar="SHELL",
-    nargs="?",
-    help="Print the command line to be eval'd by the shell",
-)
+
+@Option("--pep582", const="AUTO", metavar="SHELL", nargs="?", help="Print the command line to be eval'd by the shell")
+def pep582_option(project: Project, namespace: argparse.Namespace, values: str | Sequence[Any] | None) -> None:
+    print_pep582_command(project, cast(str, values))
+    sys.exit(0)
+
 
 install_group = ArgumentGroup("Install options")
 install_group.add_argument(
@@ -161,25 +166,14 @@ install_group.add_argument(
     dest="no_self",
     help="Don't install the project itself",
 )
+install_group.add_argument("--fail-fast", "-x", action="store_true", help="Abort on first installation error")
 
 
-def no_isolation_callback(
-    parser: argparse.ArgumentParser,
-    namespace: argparse.Namespace,
-    values: str | Sequence[Any] | None,
-    option_string: str | None,
-) -> None:
+@Option("--no-isolation", dest="build_isolation", nargs=0, help="Do not isolate the build in a clean environment")
+def no_isolation_option(project: Project, namespace: argparse.Namespace, values: str | Sequence[Any] | None) -> None:
     os.environ["PDM_BUILD_ISOLATION"] = "no"
 
 
-no_isolation_option = Option(
-    "--no-isolation",
-    dest="build_isolation",
-    action=CallbackAction,
-    nargs=0,
-    help="Do not isolate the build in a clean environment",
-    callback=no_isolation_callback,
-)
 install_group.options.append(no_isolation_option)
 
 groups_group = ArgumentGroup("Dependencies selection")
@@ -188,8 +182,8 @@ groups_group.add_argument(
     "--group",
     dest="groups",
     metavar="GROUP",
-    action="append",
-    help="Select group of optional-dependencies "
+    action=split_lists(","),
+    help="Select group of optional-dependencies separated by comma "
     "or dev-dependencies(with -d). Can be supplied multiple times, "
     'use ":all" to include all groups under the same species.',
     default=[],
@@ -206,7 +200,7 @@ dev_group = ArgumentGroup("dev", is_mutually_exclusive=True)
 dev_group.add_argument(
     "-d",
     "--dev",
-    default=True,
+    default=None,
     dest="dev",
     action="store_true",
     help="Select dev dependencies",
@@ -320,12 +314,16 @@ packages_group.add_argument(
 )
 packages_group.add_argument("packages", nargs="*", help="Specify packages")
 
-ignore_python_option = Option(
+
+@Option(
     "-I",
     "--ignore-python",
-    action="store_true",
-    help="Ignore the Python path saved in the .pdm.toml config",
+    nargs=0,
+    help="Ignore the Python path saved in .pdm-python. [env var: PDM_IGNORE_SAVED_PYTHON]",
 )
+def ignore_python_option(project: Project, namespace: argparse.Namespace, values: str | Sequence[Any] | None) -> None:
+    os.environ.update({"PDM_IGNORE_SAVED_PYTHON": "1"})
+
 
 prerelease_option = Option(
     "--pre",
@@ -341,3 +339,14 @@ unconstrained_option = Option(
     default=False,
     help="Ignore the version constraint of packages",
 )
+
+
+venv_option = Option(
+    "--venv",
+    dest="use_venv",
+    metavar="NAME",
+    nargs="?",
+    const="in-project",
+    help="Run the command in the virtual environment with the given key. [env var: PDM_IN_VENV]",
+    default=os.getenv("PDM_IN_VENV"),
+)
