@@ -25,7 +25,7 @@ from resolvelib.structs import DirectedGraph
 from rich.tree import Tree
 
 from pdm import termui
-from pdm.exceptions import PdmArgumentError, PdmUsageError, ProjectError
+from pdm.exceptions import PdmArgumentError, ProjectError
 from pdm.formats import FORMATS
 from pdm.formats.base import make_array, make_inline_table
 from pdm.models.requirements import (
@@ -300,9 +300,7 @@ def add_package_to_reverse_tree(
 
 
 def package_is_project(package: Package, project: Project) -> bool:
-    return (
-        not project.environment.is_global and project.name is not None and package.name == normalize_name(project.name)
-    )
+    return project.name is not None and package.name == normalize_name(project.name)
 
 
 def _format_forward_dependency_graph(project: Project, graph: DirectedGraph) -> Tree:
@@ -597,35 +595,6 @@ def format_resolution_impossible(err: ResolutionImpossible) -> str:
     return "\n".join(result)
 
 
-def translate_groups(project: Project, default: bool, dev: bool, groups: Iterable[str]) -> list[str]:
-    """Translate default, dev and groups containing ":all" into a list of groups"""
-    optional_groups = set(project.pyproject.metadata.get("optional-dependencies", {}))
-    dev_groups = set(project.pyproject.settings.get("dev-dependencies", {}))
-    groups_set = set(groups)
-    if dev is None:
-        dev = True
-    if groups_set & dev_groups:
-        if not dev:
-            raise PdmUsageError("--prod is not allowed with dev groups and should be left")
-    elif dev:
-        groups_set.update(dev_groups)
-    if ":all" in groups:
-        groups_set.discard(":all")
-        groups_set.update(optional_groups)
-    if default:
-        groups_set.add("default")
-    # Sorts the result in ascending order instead of in random order
-    # to make this function pure
-    invalid_groups = groups_set - set(project.iter_groups())
-    if invalid_groups:
-        project.core.ui.echo(
-            f"[d]Ignoring non-existing groups: [success]{', '.join(invalid_groups)}[/]",
-            err=True,
-        )
-        groups_set -= invalid_groups
-    return sorted(groups_set)
-
-
 def merge_dictionary(target: MutableMapping[Any, Any], input: Mapping[Any, Any]) -> None:
     """Merge the input dict with the target while preserving the existing values
     properly. This will update the target dictionary in place.
@@ -646,7 +615,6 @@ def fetch_hashes(repository: BaseRepository, mapping: Mapping[str, Candidate]) -
     """Fetch hashes for candidates in parallel"""
 
     def do_fetch(candidate: Candidate) -> None:
-        termui.logger.info("Fetching hashes for %s", candidate)
         candidate.hashes = repository.get_hashes(candidate)
 
     with ThreadPoolExecutor() as executor:
@@ -692,3 +660,14 @@ def get_pep582_path(project: Project) -> str:
     with resources_open_binary("pdm.pep582", "sitecustomize.py") as f:
         script_dir.joinpath("sitecustomize.py").write_bytes(f.read())
     return str(script_dir)
+
+
+def use_venv(project: Project, name: str) -> None:
+    from pdm.cli.commands.venv.utils import get_venv_python, get_venv_with_name
+    from pdm.environments import PythonEnvironment
+
+    venv = get_venv_with_name(project, cast(str, name))
+    project.core.ui.echo(
+        f"In virtual environment: [success]{venv}[/]", err=True, style="info", verbosity=termui.Verbosity.DETAIL
+    )
+    project.environment = PythonEnvironment(project, python=str(get_venv_python(venv)))
