@@ -5,16 +5,18 @@ import functools
 import multiprocessing
 import traceback
 from concurrent.futures import Future, ThreadPoolExecutor
+from types import SimpleNamespace
 from typing import TYPE_CHECKING, Any, Callable, Collection, TypeVar
 
 from rich.progress import SpinnerColumn
 
 from pdm import termui
+from pdm.compat import cached_property
+from pdm.environments import BaseEnvironment
 from pdm.exceptions import InstallationError
 from pdm.installers.manager import InstallManager
 from pdm.models.candidates import Candidate, make_candidate
-from pdm.models.environment import Environment
-from pdm.models.requirements import Requirement, parse_requirement, strip_extras
+from pdm.models.requirements import FileRequirement, Requirement, parse_requirement, strip_extras
 from pdm.utils import is_editable, normalize_name
 
 if TYPE_CHECKING:
@@ -48,6 +50,9 @@ class DummyFuture:
     def add_done_callback(self: _T, func: Callable[[_T], Any]) -> None:
         func(self)
 
+    def cancel(self) -> bool:
+        return False
+
 
 class DummyExecutor:
     """A synchronous pool class to mimic ProcessPoolExecuter's interface.
@@ -69,7 +74,7 @@ class DummyExecutor:
         return
 
 
-def editables_candidate(environment: Environment) -> Candidate | None:
+def editables_candidate(environment: BaseEnvironment) -> Candidate | None:
     """Return a candidate for `editables` package"""
     repository = environment.project.get_repository()
     return next(iter(repository.find_candidates(parse_requirement("editables"))), None)
@@ -89,6 +94,7 @@ class Synchronizer:
     :param use_install_cache: whether to use install cache
     :param reinstall: whether to reinstall all packages
     :param only_keep: If true, only keep the selected candidates
+    :param fail_fast: If true, stop the installation on first error
     """
 
     SEQUENTIAL_PACKAGES = ("pip", "setuptools", "wheel")
@@ -96,7 +102,7 @@ class Synchronizer:
     def __init__(
         self,
         candidates: dict[str, Candidate],
-        environment: Environment,
+        environment: BaseEnvironment,
         clean: bool = False,
         dry_run: bool = False,
         retry_times: int = 1,
@@ -105,7 +111,9 @@ class Synchronizer:
         use_install_cache: bool = False,
         reinstall: bool = False,
         only_keep: bool = False,
+        fail_fast: bool = False,
     ) -> None:
+        self.requested_candidates = candidates
         self.environment = environment
         self.clean = clean
         self.dry_run = dry_run
@@ -115,39 +123,46 @@ class Synchronizer:
         self.use_install_cache = use_install_cache
         self.reinstall = reinstall
         self.only_keep = only_keep
-
         self.parallel = environment.project.config["install.parallel"]
-        locked_repository = environment.project.locked_repository
-        self.all_candidate_keys = list(locked_repository.all_candidates)
+        self.fail_fast = fail_fast
+
         self.working_set = environment.get_working_set()
         self.ui = environment.project.core.ui
-        self.self_candidate: Candidate | None = None
-        if self.install_self:
-            self.self_candidate = self.environment.project.make_self_candidate(not self.no_editable)
+        self._manager: InstallManager | None = None
 
+    @cached_property
+    def self_candidate(self) -> Candidate:
+        """Return the candidate for self project"""
+        return self.environment.project.make_self_candidate(not self.no_editable)
+
+    @cached_property
+    def candidates(self) -> dict[str, Candidate]:
+        """Return the candidates to be installed"""
+        candidates = self.requested_candidates.copy()
         if isinstance(self.no_editable, Collection):
             keys = self.no_editable
         elif self.no_editable:
             keys = candidates.keys()
         else:
             keys = []
-            if self.should_install_editables() and "editables" not in candidates:
+            if self.should_install_editables():
                 # Install `editables` as well as required by self project
-                editables = editables_candidate(environment)
+                editables = editables_candidate(self.environment)
                 if editables is not None:
                     candidates["editables"] = editables
         for key in keys:
             if key in candidates and candidates[key].req.editable:
-                # We do not do in-place update, which will break the caches
                 candidate = candidates[key]
+                # Create a new candidate with editable=False
                 req = dataclasses.replace(candidate.req, editable=False)
                 candidates[key] = make_candidate(req, candidate.name, candidate.version, candidate.link)
-        self.candidates = candidates
-        self._manager: InstallManager | None = None
+        return candidates
 
     def should_install_editables(self) -> bool:
-        if self.self_candidate is None:
+        """Return whether to add editables"""
+        if not self.install_self or "editables" in self.requested_candidates:
             return False
+        # As editables may be added by the backend, we need to check the metadata
         metadata = self.self_candidate.prepare(self.environment).metadata
         return any(req.startswith("editables") for req in metadata.requires or [])
 
@@ -186,7 +201,10 @@ class Synchronizer:
             return bool(self.no_editable)
         if not can.req.is_named:
             dreq = Requirement.from_dist(dist)
-            return getattr(dreq, "url", None) != backend.expand_line(can.req.url)  # type: ignore[attr-defined]
+            if not isinstance(dreq, FileRequirement):
+                return True
+            assert can.link is not None
+            return dreq.get_full_url() != backend.expand_line(can.link.url_without_fragment)
         specifier = can.req.as_pinned_version(can.version).specifier
         assert specifier is not None
         return not specifier.contains(dist.version, prereleases=True)
@@ -197,6 +215,8 @@ class Synchronizer:
         candidates = self.candidates.copy()
         to_update: set[str] = set()
         to_remove: set[str] = set()
+        locked_repository = self.environment.project.locked_repository
+        all_candidate_keys = list(locked_repository.all_candidates)
 
         for key, dist in working_set.items():
             if key == self.self_key:
@@ -206,7 +226,7 @@ class Synchronizer:
                 if self._should_update(dist, can):
                     to_update.add(key)
             elif (
-                self.only_keep or self.clean and key not in self.all_candidate_keys
+                self.only_keep or self.clean and key not in all_candidate_keys
             ) and key not in self.SEQUENTIAL_PACKAGES:
                 # Remove package only if it is not required by any group
                 # Packages for packaging will never be removed
@@ -356,19 +376,22 @@ class Synchronizer:
                 else:
                     parallel_jobs.append((kind, key))
 
-        errors: list[str] = []
-        failed_jobs: list[tuple[str, str]] = []
+        state = SimpleNamespace(errors=[], failed_jobs=[], jobs=[], mark_failed=False)
 
         def update_progress(future: Future | DummyFuture, kind: str, key: str) -> None:
             error = future.exception()
             if error:
                 exc_info = (type(error), error, error.__traceback__)
                 termui.logger.exception("Error occurs: ", exc_info=exc_info)
-                failed_jobs.append((kind, key))
-                errors.extend([f"{kind} [success]{key}[/] failed:\n", *traceback.format_exception(*exc_info)])
+                state.failed_jobs.append((kind, key))
+                state.errors.extend([f"{kind} [success]{key}[/] failed:\n", *traceback.format_exception(*exc_info)])
+                if self.fail_fast:
+                    for future in state.jobs:
+                        future.cancel()
+                    state.mark_failed = True
 
         # get rich progress and live handler to deal with multiple spinners
-        with self.ui.logging("install"), self.ui.make_progress(
+        with self.ui.make_progress(
             " ",
             SpinnerColumn(termui.SPINNER, speed=1, style="primary"),
             "{task.description}",
@@ -377,25 +400,27 @@ class Synchronizer:
             for kind, key in sequential_jobs:
                 handlers[kind](key, progress)
             for i in range(self.retry_times + 1):
+                state.jobs.clear()
                 with self.create_executor() as executor:
                     for kind, key in parallel_jobs:
                         future = executor.submit(handlers[kind], key, progress)
                         future.add_done_callback(functools.partial(update_progress, kind=kind, key=key))
-                if not failed_jobs or i == self.retry_times:
+                        state.jobs.append(future)
+                if state.mark_failed or not state.failed_jobs or i == self.retry_times:
                     break
-                parallel_jobs, failed_jobs = failed_jobs, []
-                errors.clear()
+                parallel_jobs, state.failed_jobs = state.failed_jobs, []
+                state.errors.clear()
                 live.console.print("Retry failed jobs")
 
-            if errors:
+            if state.errors:
                 if self.ui.verbosity < termui.Verbosity.DETAIL:
                     live.console.print("\n[error]ERRORS[/]:")
-                    live.console.print("".join(errors), end="")
+                    live.console.print("".join(state.errors), end="")
                 raise InstallationError("Some package operations are not complete yet")
 
             if self.install_self:
                 self_key = self.self_key
-                assert self_key and self.self_candidate
+                assert self_key
                 self.candidates[self_key] = self.self_candidate
                 word = "a" if self.no_editable else "an editable"
                 live.console.print(f"Installing the project as {word} package...")
