@@ -436,7 +436,7 @@ def filter_requirements_with_extras(
 
     extras_not_found = [e for e in extras if e not in extras_in_meta]
     if extras_not_found:
-        warnings.warn(ExtrasWarning(project_name, extras_not_found))
+        warnings.warn(ExtrasWarning(project_name, extras_not_found), stacklevel=2)
 
     return result
 
@@ -473,7 +473,10 @@ def parse_requirement(line: str, editable: bool = False) -> Requirement:
             m = _file_req_re.match(line)
             if m is None:
                 raise RequirementError(str(e)) from None
-            r = FileRequirement.create(**m.groupdict())
+            args = m.groupdict()
+            if not args["url"] and args["path"] and not os.path.exists(args["path"]):
+                raise RequirementError(str(e)) from None
+            r = FileRequirement.create(**args)
         else:
             r = Requirement.from_pkg_requirement(pkg_req)
         if replaced:
