@@ -53,11 +53,11 @@ from pdm.cli.actions import do_init
 from pdm.cli.hooks import HookManager
 from pdm.compat import Protocol
 from pdm.core import Core
+from pdm.environments import BaseEnvironment, PrefixEnvironment
 from pdm.exceptions import CandidateInfoNotFound
 from pdm.installers.installers import install_wheel
 from pdm.models.backends import get_backend
 from pdm.models.candidates import Candidate
-from pdm.models.environment import Environment, PrefixEnvironment
 from pdm.models.repositories import BaseRepository
 from pdm.models.requirements import (
     Requirement,
@@ -72,7 +72,7 @@ from pdm.utils import find_python_in_path, normalize_name, path_to_url
 if TYPE_CHECKING:
     from _pytest.fixtures import SubRequest
 
-    from pdm._types import CandidateInfo, Source
+    from pdm._types import CandidateInfo, RepositoryConfig
 
 
 class LocalFileAdapter(requests.adapters.BaseAdapter):
@@ -153,7 +153,7 @@ class TestRepository(BaseRepository):
     A mock repository to ease testing dependencies
     """
 
-    def __init__(self, sources: list[Source], environment: Environment, pypi_json: Path):
+    def __init__(self, sources: list[RepositoryConfig], environment: BaseEnvironment, pypi_json: Path):
         super().__init__(sources, environment)
         self._pypi_data: dict[str, Any] = {}
         self._pypi_json = pypi_json
@@ -319,7 +319,7 @@ def build_env(build_env_wheels: Iterable[Path], tmp_path_factory: pytest.TempPat
     """
     d = tmp_path_factory.mktemp("pdm-test-env")
     p = Core().create_project(d)
-    env = PrefixEnvironment(p, str(d))
+    env = PrefixEnvironment(p, prefix=str(d))
     for wheel in build_env_wheels:
         install_wheel(str(wheel), env)
     return d
@@ -388,14 +388,14 @@ def project_no_init(
     )
     p = core.create_project(tmp_path, global_config=test_home.joinpath("config.toml").as_posix())
     p.global_config["venv.location"] = str(tmp_path / "venvs")
-    mocker.patch("pdm.models.environment.PDMSession", pdm_session)
+    mocker.patch("pdm.environments.base.PDMSession", pdm_session)
     mocker.patch("pdm.builders.base.EnvBuilder.get_shared_env", return_value=str(build_env))
     tmp_path.joinpath("caches").mkdir(parents=True)
     p.global_config["cache_dir"] = tmp_path.joinpath("caches").as_posix()
     python_path = find_python_in_path(sys.base_prefix)
     if python_path is None:
         raise ValueError("Unable to find a Python path")
-    p.project_config["python.path"] = python_path.as_posix()
+    p._saved_python = python_path.as_posix()
     monkeypatch.delenv("VIRTUAL_ENV", raising=False)
     monkeypatch.delenv("CONDA_PREFIX", raising=False)
     monkeypatch.delenv("PEP582_PACKAGES", raising=False)
@@ -437,7 +437,7 @@ def working_set(mocker: MockerFixture, repository: TestRepository) -> MockWorkin
         a mock working set
     """
     rv = MockWorkingSet()
-    mocker.patch.object(Environment, "get_working_set", return_value=rv)
+    mocker.patch.object(BaseEnvironment, "get_working_set", return_value=rv)
 
     def install(candidate: Candidate) -> None:
         key = normalize_name(candidate.name or "")
@@ -617,6 +617,8 @@ def pdm(core: Core, monkeypatch: pytest.MonkeyPatch) -> PDMCallable:
         result = RunResult(exit_code, stdout.getvalue(), stderr.getvalue(), exception)
 
         if strict and result.exit_code != 0:
+            if result.exception:
+                raise result.exception.with_traceback(result.exception.__traceback__)
             raise RuntimeError(f"Call command {args} failed({result.exit_code}): {result.stderr}")
         return result
 
